@@ -436,34 +436,33 @@ void pdl_dump_trans_fixspace (pdl_trans *it, int nspac) {
 	printf(")\n");
 }
 
-void pdl_dump_fixspace(pdl *it,int nspac)
-{
-	PDL_DECL_CHILDLOOP(it)
-	PDL_Indx i;
-	SET_SPACE(spaces, nspac);
-	printf("%sDUMPING %p     datatype: %d\n%s   State: ",spaces,(void*)it,it->datatype,spaces);
-	pdl_dump_flags_fixspace(it->state,nspac+3,PDL_FLAGS_PDL);
-	printf("%s   transvtable: %p, trans: %p, sv: %p\n",spaces,
-		(void*)(it->trans_parent?it->trans_parent->vtable:0), (void*)(it->trans_parent), (void*)(it->sv));
-	if (it->datasv)
-		printf("%s   datasv: %p, Svlen: %d, refcnt: %d\n", spaces,
-			(void*)it->datasv, (int)SvCUR((SV*)it->datasv), (int)SvREFCNT((SV*)it->datasv));
-	if (it->data)
-		printf("%s   data: %p, nbytes: %"IND_FLAG", nvals: %"IND_FLAG"\n", spaces,
-			(void*)(it->data), it->nbytes, it->nvals);
-	if (it->hdrsv)
-		printf("%s   hdrsv: %p, reftype %s\n", spaces,
-			(void*)it->hdrsv, sv_reftype((SV*)it->hdrsv, TRUE));
-	printf("%s   Dims: %p ",spaces,(void*)it->dims);
-	pdl_print_iarr(it->dims, it->ndims);
-	printf("\n%s   BroadcastIds: %p ",spaces,(void*)(it->broadcastids));
-	pdl_print_iarr(it->broadcastids, it->nbroadcastids);
-	if (it->vafftrans) {
-		printf("\n%s   Vafftrans: %p (parent), o:%"IND_FLAG", i:",
-			spaces,(void*)(it->vafftrans->from),it->vafftrans->offs);
-		pdl_print_iarr(PDL_REPRINCS(it), it->vafftrans->ndims);
-	}
-	if (it->state & PDL_BADVAL) {
+void pdl_dump_fixspace(pdl *it,int nspac) {
+  PDL_DECL_CHILDLOOP(it)
+  PDL_Indx i;
+  SET_SPACE(spaces, nspac);
+  printf("%sDUMPING %p     datatype: %d\n%s   State: ",spaces,(void*)it,it->datatype,spaces);
+  pdl_dump_flags_fixspace(it->state,nspac+3,PDL_FLAGS_PDL);
+  printf("%s   transvtable: %p, trans: %p, sv: %p\n",spaces,
+    (void*)(it->trans_parent?it->trans_parent->vtable:0), (void*)(it->trans_parent), (void*)(it->sv));
+  if (it->datasv)
+    printf("%s   datasv: %p, Svlen: %lld, refcnt: %lld\n", spaces,
+      (void*)it->datasv, (long long)SvCUR((SV*)it->datasv), (long long)SvREFCNT((SV*)it->datasv));
+  if (it->data)
+    printf("%s   data: %p, nbytes: %"IND_FLAG", nvals: %"IND_FLAG"\n", spaces,
+      (void*)(it->data), it->nbytes, it->nvals);
+  if (it->hdrsv)
+    printf("%s   hdrsv: %p, reftype %s\n", spaces,
+      (void*)it->hdrsv, sv_reftype((SV*)it->hdrsv, TRUE));
+  printf("%s   Dims: %p ",spaces,(void*)it->dims);
+  pdl_print_iarr(it->dims, it->ndims);
+  printf("\n%s   BroadcastIds: %p ",spaces,(void*)(it->broadcastids));
+  pdl_print_iarr(it->broadcastids, it->nbroadcastids);
+  if (it->vafftrans) {
+    printf("\n%s   Vafftrans: %p (parent), o:%"IND_FLAG", i:",
+      spaces,(void*)(it->vafftrans->from),it->vafftrans->offs);
+    pdl_print_iarr(PDL_REPRINCS(it), it->vafftrans->ndims);
+  }
+  if (it->state & PDL_BADVAL) {
           printf("\n%s   Badvalue (%s): ",spaces, it->has_badvalue ? "bespoke" : "orig");
           PDL_Anyval result = { PDL_INVALID, {0} };
           if (!(it->has_badvalue && it->badvalue.type != it->datatype)) {
@@ -480,27 +479,28 @@ void pdl_dump_fixspace(pdl *it,int nspac)
             printf("ERROR getting badval");
           else
             pdl_dump_anyval(result);
-	}
-	if (it->state & PDL_ALLOCATED) {
-		printf("\n%s   First values: (",spaces);
-		for (i=0; i<it->nvals && i<10; i++) {
+  }
+  if (it->state & PDL_ALLOCATED) {
+    printf("\n%s   First values: (",spaces);
+    for (i=0; i<it->nvals && i<10; i++) {
                        if (i) printf(" ");
                        PDL_Anyval result = { PDL_INVALID, {0} };
                        ANYVAL_FROM_CTYPE_OFFSET(result, it->datatype, it->data, i);
                        pdl_dump_anyval(result);
-		}
-	} else {
-		printf("\n%s   (not allocated",spaces);
-	}
-	printf(")\n");
-	if (it->trans_parent) {
-		pdl_dump_trans_fixspace(it->trans_parent,nspac+3);
-	}
-	printf("%s   CHILDREN:\n",spaces);
-	PDL_START_CHILDLOOP(it)
-		pdl_dump_trans_fixspace(PDL_CHILDLOOP_THISCHILD(it),nspac+4);
-	PDL_END_CHILDLOOP(it)
-	/* XXX phys etc. also */
+    }
+  } else {
+    printf("\n%s   (not allocated",spaces);
+  }
+  printf(")\n");
+  if (it->trans_parent) {
+    pdl_dump_trans_fixspace(it->trans_parent,nspac+3);
+  }
+  if (it->ntrans_children) {
+    printf("%s   CHILDREN:\n",spaces);
+    PDL_START_CHILDLOOP(it)
+      pdl_dump_trans_fixspace(PDL_CHILDLOOP_THISCHILD(it),nspac+4);
+    PDL_END_CHILDLOOP(it)
+  }
 }
 
 void pdl_dump (pdl *it) {
