@@ -82,17 +82,15 @@ and everything else works the way you think it should.
 =cut
 
 package PDL::Matrix;
+use strict;
+use warnings;
 
-@EXPORT_OK = ();
-
-
-#use PDL::Core;
-#use PDL::Slatec;
 use PDL::Exporter;
 use Carp;
 
-@ISA = qw/PDL::Exporter PDL/;
-
+our @EXPORT_OK;
+our %EXPORT_TAGS = (Func=>\@EXPORT_OK);
+our @ISA = qw/PDL::Exporter PDL/;
 our $VERSION = "0.5";
 $VERSION = eval $VERSION;
 
@@ -169,7 +167,7 @@ dimensions (n x 1)
 
 sub vpdl {
   my $pdl = PDL->pdl(@_);
-  bless $pdl, PDL::Matrix;
+  bless $pdl, __PACKAGE__;
 }
 push @EXPORT_OK, "vpdl";
 
@@ -206,16 +204,7 @@ EOE
   eval $code;
 }
 
-
-
-eval "use PDL::Slatec";
-
-my $has_slatec = ($@ ? 0 : 1);
-sub inv {
-  my $self = shift;
-  croak "inv: PDL::Slatec not available" unless $has_slatec;
-  return $self->matinv;
-}
+sub inv { shift->transpose->SUPER::inv->transpose }
 
 =head2 kroneckerproduct
 
@@ -380,8 +369,6 @@ sub printTeX {
   print stringifyTeX(@_)."\n";
 }
 
-%EXPORT_TAGS = (Func=>[@EXPORT_OK]);
-
 1;
 
 =head1 BUGS AND PROBLEMS
