@@ -36,13 +36,13 @@ use warnings;
 
 ################################################################################
 # figure out what's good in an ndarray after a possible transformation which could
-# generate Infs or NaN's.  If only everyone used PDL::Bad::UseNaN...
+# generate Infs or NaN's.
 sub set_mask
 {
   my ( $mask, $data ) = @_;
   my $badflag = $data->badflag();
   $data->badflag(1);
-  $mask .= $PDL::Bad::UseNaN ? (! $data->isbad ) : ( $data->isfinite & ! $data->isbad );
+  $mask .= ( $data->isfinite & ! $data->isbad );
   $data->badflag($badflag);
 }
 
@@ -206,7 +206,6 @@ sub set_mask
 
 #####################################################################
 
-# based upon PGPLOT's pgrnge routine.
 sub range_frac
 {
   my ( $axis, $frac, $zerofix ) = @_;
@@ -229,8 +228,6 @@ sub range_frac
 
 #####################################################################
 
-# based upon PGPLOT's pgrnd routine
-
 #  routine to find the closest "round" number to X, a "round" number
 #  being 1, 2 or 5 times a power of 10.
 
