@@ -85,16 +85,17 @@ See the documentation for the OpenGL module.
 More details to follow as the refactored TriD module
 interface and build environment matures
 
+=head1 CONFIG
+
+Defaults to using L<OpenGL::GLUT> - override by setting the environment
+variable C<POGL_WINDOW_TYPE> to C<x11> (the default is C<glut>).
+
 =head1 FUNCTIONS
 
 =head2 TBD
 
 =cut
 
-=head2 TBD
-
-=cut
-
 package PDL::Graphics::OpenGL::OO;
 use PDL::Graphics::TriD::Window qw();
 use PDL::Options;
@@ -157,14 +158,14 @@ sub new {
    if($isref and defined $class_or_hash->{Options}){
       $p = $class_or_hash->{Options};
    }else{
-      my $opt = new PDL::Options(default_options());
+      my $opt = PDL::Options->new(default_options());
       $opt->incremental(1);
       $opt->options($options) if(defined $options);
       $p = $opt->options;
    }
 
    # Use GLUT windows and event handling as the TriD default
-   $window_type ||= $PDL::Config{POGL_WINDOW_TYPE};
+   $window_type ||= $ENV{POGL_WINDOW_TYPE} || 'glut';
    # $window_type ||= 'x11';       # use X11 default until glut code is ready
 
    my $self;
